# PipeScope: Pipeline visualization for CPU microarchitecture traces
#
# Copyright (c) 2026 Microprocessor R&D Center (MPRC), Peking University
# SPDX-License-Identifier: MulanPSL-2.0
#
# Author: Chun Yang

"""Trace data processing."""

from .inst_rec import InstRec

__all__ = ["InstRec"]
