# PipeScope: Pipeline visualization for CPU microarchitecture traces
#
# Copyright (c) 2026 Microprocessor R&D Center (MPRC), Peking University
# SPDX-License-Identifier: MulanPSL-2.0
#
# Author: Chun Yang

"""PipeScope backend package."""

__version__ = "0.6.0"
